pub struct Config {
pub client_id: String,
pub client_secret: String,
pub refresh_token: String,
pub access_token: Option<String>,
pub token_refresh_threshold: u64,
pub token_expiry_buffer: u64,
}Fields
client_id: Stringclient_secret: Stringrefresh_token: Stringaccess_token: Option<String>token_refresh_threshold: u64Number of seconds before an access token expires that it should be refreshed. Allows for proactive refresh to prevent working with nearly-expired tokens. Can be configured with TOKEN_REFRESH_THRESHOLD_SECONDS environment variable.
token_expiry_buffer: u64Buffer time in seconds subtracted from the token’s expiration time to ensure we don’t use tokens too close to their expiry time. Provides a safety margin. Can be configured with TOKEN_EXPIRY_BUFFER_SECONDS environment variable.
Implementations